#!/usr/bin/env python
# -*- coding: utf-8 -*-
import haystack


#haystack.autodiscover()
